@@ -16,9 +16,9 @@ setMethod(f = "plot", signature(x = "PortDD", y = "missing"), definition = funct
   if(is.null(xlab)){xlab <- ""}
   if(is.null(ylab)){ylab <- "Draw Downs (percentages)"}
   if(length(col) < 2) col <- c(col[1], col[1])
-  if(class(x) == "PortMdd") level <- x@MaxDD
-  if(class(x) == "PortAdd") level <- x@AveDD
-  if(class(x) == "PortCdd") level <- x@CDaR
+  if(inherits(x, "PortMdd")) level <- x@MaxDD
+  if(inherits(x, "PortAdd")) level <- x@AveDD
+  if(inherits(x, "PortCdd")) level <- x@CDaR
   if(invert){
     dd <- -1.0 * dd
     level <- -1.0 * level
